@@ -6,14 +6,18 @@
  * <http://kldp.net/projects/cdic>
  *    
  *  
- * Compile
+ * Compile (ko_KR.eucKR)
  * [bando@bando cdic-1.0]$ gcc -o cdic cdic.c 
+ *
+ *
+ * Compile (ko_KR.UTF-8)
+ * [bando@bando cdic-1.0]$ gcc -o cdic -DHAVE_ICONV -DHAVE_UTF8 cdic.c
  * 
  * 
  * Usage
  * [bando@bando cdic-1.0]$ ./cdic [word] or [text]
  * 
- * $Id: cdic.c,v 1.5 2008/01/11 13:33:04 bando Exp $
+ * $Id: cdic.c,v 1.8 2008/01/20 14:27:02 bando Exp $
  * 
  */
 
@@ -40,7 +44,7 @@
 #include <arpa/inet.h>
 
 #define PROG_NAME "cdic"
-#define PROG_VERSION "1.0"
+#define PROG_VERSION "1.1.2"
 #define CONF_F ".cdic"
 
 #define SUCCESS 0
@@ -1005,6 +1009,7 @@ void http_request_free (http_request *hr)
         if (hr->host) free(hr->host);
         if (hr->uri) free(hr->uri);
         if (hr->rhdr) free(hr->rhdr);
+        if (hr) free(hr);
 }
 
 
@@ -1277,7 +1282,11 @@ void config_init (config *cf)
 	cf->trans = 0;
 #ifdef HAVE_ICONV
 	memset(cf->charset, 0x0, sizeof(cf->charset));
+#ifndef HAVE_UTF8
 	strncpy(cf->charset, CDSET, sizeof(cf->charset) - 1);
+#else
+	strncpy(cf->charset, "UTF-8", sizeof(cf->charset) - 1);
+#endif
 #endif
 }
 
